﻿------------------------------------------------------------------------------
-- $Id$
------------------------------------------------------------------------------
--                                options.lua
--
--	Copyright (C) 2012 Maighurl, Deronda
--
--  This file is for use with clcInfo by abija.  Some of the code was pulled
--  from existing clcInfo modules and the example module.
--
--  abija has distributed clcInfo All Rights Reserved.  For more information
--  go to: http://wow.curseforge.com/addons/clctracker/
--
------------------------------------------------------------------------------
-- Author:
--      Maighurl, Deronda (@ Stormreaver)
------------------------------------------------------------------------------
-- Description:
--   Options for clcInfo_Warlock
------------------------------------------------------------------------------
if not clcInfo then return end --clcInfo must be loaded
if not clcInfo_Warlock then return end

local _, englishClass = UnitClass("player")
if englishClass ~= clcInfo_Warlock.CLASS then return end  --must be Warlock

--each spec needs its own set and get functions to refer to their
--own db and tdb upvalues.  So we use closures for Get and Set functions for
--the AceGUI callbacks.
function clcInfo_Warlock.newGetDB(db)
    return function (info)
               return db[info[#info]]
           end
end

function clcInfo_Warlock.newSetDB(db)
    return function (info, val)
               db[info[#info]] = val
           end
end

function clcInfo_Warlock.newGetTDB(tdb)
    return function (info)
               return tdb[info[#info]]
           end
end

function clcInfo_Warlock.newSetTDB(tdb)
    return function (info, val)
               tdb[info[#info]] = val
           end
end

function clcInfo_Warlock.newGetPriority(tdb)
    return function (info)
               local i = tonumber(info[#info])
               return tdb.priority[i]
           end
end

function clcInfo_Warlock.newSetPriority(tdb, actions, spec)
    return function (info, val)
               local i = tonumber(info[#info])
               tdb.priority[i] = val
               clcInfo_Warlock.UpdateQueue(actions, tdb, spec)
           end
end

--Create a module options screen
function clcInfo_Warlock.LoadModule(class_module_name, talent_tree_name,
                                    sample_prio, actions, GetDB, SetDB, GetTDB,
                                    SetTDB, GetPriority, SetPriority)

    clcInfo_Options.options.args.classModules.args[class_module_name] = {
        order = 2, type = "group", childGroups = "tab", name = talent_tree_name,
        args = {
            tabPriority = {
                order = 1, type = "group", name = ABILITIES, args = {
                    igSettings = {
                        order = 1, type = "group", inline = true, name=SETTINGS,
                        args = {
                            rangePerSkill = {
                                order = 1, type = "toggle", width = "full",
                                name = format("%s/%s", RANGED, SKILL),
                                get = GetTDB, set = SetTDB,
                            },
                        },
                    },
                    prioSettings = {
                        order = 2, type = "group", inline = true, name = RANK,
                        args = {} -- place holder for priorities
                    },
                },           
            },
        },
    }

    -- generate priorities interface (fill in the place holder!!)
    local spellChoice = { none = "None" }
    local num = 0
	for key, action in pairs(actions) do
		spellChoice[key] = action.info
        num = num + 1
	end

    local prioArgs = clcInfo_Options.options.args.classModules
                     .args[class_module_name].args.tabPriority.args
                     .prioSettings.args
    for i = 1, num do
        prioArgs[tostring(i)] = {
            order = i, type = "select", name = tostring(i), 
            get = GetPriority, set = SetPriority, values = spellChoice,
        }
    end
end
